==> record_api-1.0.0.tar.gz: record_api-1.0.0/data/typing/pandas.core.reshape.merge.py <==
from typing import *


def merge(
    _0: Union[dask.dataframe.core.DataFrame, pandas.core.frame.DataFrame] = ...,
    _1: Union[dask.dataframe.core.DataFrame, pandas.core.frame.DataFrame] = ...,
    /,
    left: Union[dask.dataframe.core.DataFrame, pandas.core.frame.DataFrame] = ...,
    right: Union[dask.dataframe.core.DataFrame, pandas.core.frame.DataFrame] = ...,
    how: Literal["inner", "outer", "left", "right"] = ...,
    on: Union[
        Literal["KEY", "B", "x", "y", "idx"], List[Literal["idx", "k", "A"]], None
    ] = ...,
    left_on: Union[
        None, str, List[Literal["y", "b", "a"]], dask.dataframe.core.Series
    ] = ...,
    right_on: Union[
        None, dask.dataframe.core.Series, str, List[Literal["y", "e", "d"]]
    ] = ...,
    left_index: bool = ...,
    right_index: bool = ...,
    suffixes: Union[
        Tuple[Literal["1", "_x"], Literal["2", "_y"]],
        List[Literal["_r", "_l", "", "r", "l"]],
    ] = ...,
    indicator: bool = ...,
    *,
    npartitions: None = ...,
    shuffle: Union[None, Literal["tasks", "disk"]] = ...,
):
    """
    usage.dask: 444
    """
    ...


def merge_asof(
    left: Union[dask.dataframe.core.DataFrame, pandas.core.frame.DataFrame],
    right: Union[dask.dataframe.core.DataFrame, pandas.core.frame.DataFrame],
    left_index: bool = ...,
    right_index: bool = ...,
    left_by: Union[Literal["ticker"], None] = ...,
    right_by: Union[Literal["ticker"], None] = ...,
    suffixes: Tuple[Literal["_x"], Literal["_y"]] = ...,
    on: Literal["time", "a"] = ...,
    by: Literal["ticker"] = ...,
    tolerance: Union[pandas._libs.tslibs.timedeltas.Timedelta, None] = ...,
    allow_exact_matches: bool = ...,
    direction: Literal["backward", "nearest", "forward"] = ...,
):
    """
    usage.dask: 27
    """
    ...

==> record_api-1.2.0.tar.gz: record_api-1.2.0/data/typing/pandas.core.reshape.merge.py <==
from typing import *


def merge(
    _0: Union[dask.dataframe.core.DataFrame, pandas.core.frame.DataFrame] = ...,
    _1: Union[dask.dataframe.core.DataFrame, pandas.core.frame.DataFrame] = ...,
    /,
    left: Union[dask.dataframe.core.DataFrame, pandas.core.frame.DataFrame] = ...,
    right: Union[dask.dataframe.core.DataFrame, pandas.core.frame.DataFrame] = ...,
    how: Literal["outer", "left", "inner", "right"] = ...,
    on: Union[
        None, List[Literal["idx", "k", "A"]], Literal["B", "x", "y", "idx"]
    ] = ...,
    left_on: Union[
        None,
        dask.dataframe.core.Series,
        List[Literal["y", "b", "a"]],
        Literal["x", "e", "d", "b", "a"],
    ] = ...,
    right_on: Union[
        None, List[Literal["y", "e", "d"]], str, dask.dataframe.core.Series
    ] = ...,
    left_index: bool = ...,
    right_index: bool = ...,
    suffixes: Union[
        Tuple[Literal["1", "_x"], Literal["2", "_y"]],
        List[Literal["_r", "_l", "", "r", "l"]],
    ] = ...,
    indicator: bool = ...,
    *,
    npartitions: None = ...,
    shuffle: Union[None, Literal["tasks", "disk"]] = ...,
):
    """
    usage.dask: 291
    """
    ...


def merge_asof(
    left: Union[dask.dataframe.core.DataFrame, pandas.core.frame.DataFrame],
    right: Union[dask.dataframe.core.DataFrame, pandas.core.frame.DataFrame],
    on: Literal["time", "a"] = ...,
    by: Literal["ticker"] = ...,
    left_on: Literal["a"] = ...,
    left_index: bool = ...,
    right_index: bool = ...,
    left_by: Union[Literal["ticker"], None] = ...,
    right_by: Union[Literal["ticker"], None] = ...,
    suffixes: Tuple[Literal["_x"], Literal["_y"]] = ...,
    tolerance: Union[pandas._libs.tslibs.timedeltas.Timedelta, None] = ...,
    allow_exact_matches: bool = ...,
    direction: Literal["backward", "nearest", "forward"] = ...,
):
    """
    usage.dask: 41
    """
    ...
